.. _trojanvision.defenses:

defenses
=========

.. currentmodule:: trojanvision.defenses

.. toctree::
   :maxdepth: 3

   adv
   backdoor/index


.. autofunction:: add_argument
.. autofunction:: create

.. autoclass:: BackdoorDefense
    :members:

.. autoclass:: InputFiltering
    :members:

.. autoclass:: TrainingFiltering
    :members:

.. autoclass:: ModelInspection
    :members:
